@@ -2,7 +2,7 @@ package App::tt;
 use strict;
 use warnings;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 1;
 
@@ -14,7 +14,7 @@ App::tt - Time tracking application
 
 =head1 VERSION
 
-0.13
+0.14
 
 =head1 DESCRIPTION
 
@@ -30,24 +30,9 @@ The application is built up by specifying an command and optional arguments.
 Here is a list of example usages, but you can get more details by adding "-h"
 after each command.
 
-  # Register forgotten time
-  $ tt register 2020-01-01T09:00:00 17:00:00 -p "project-name"
-  $ tt register 2020-01-01T09:00:00 17:00:00 -p "project-name" -t "tag1,tag2"
-  $ tt register 2020-01-01T09:00:00 17:00:00 -p "project-name" -d "description" -t "tag1,tag2"
-
-  # Edit the last entry, or a specific file
-  $ tt edit
-  $ tt edit ~/.TimeTracker/2020/01/20200106-150000_nms.trc
-
-  # See the log
-  $ tt log
-  $ tt log -0year                  # Log for this year
-  $ tt log -1year -t meetings      # Log for last year, for tag "meetings"
-  $ tt log -p project-name -1month # Log for last month, for project "project-name"
-  $ tt log -2                      # Log for two months back
-
   # Start tracking time
   $ tt start
+  $ tt start -p project-name
   $ tt start -p project-name -t tag1,tag2
   $ tt start -p project-name -t tag1,tag2 09:03
 
@@ -60,6 +45,23 @@ after each command.
   $ tt stop
   $ tt stop 18:04
 
+  # See the log
+  $ tt log
+  $ tt log -0year                  # Log for this year
+  $ tt log -1year -t meetings      # Log for last year, for tag "meetings"
+  $ tt log -p project-name -1month # Log for last month, for project "project-name"
+  $ tt log -2                      # Log for two months back
+  $ tt export -1                   # Export as CSV
+
+  # Edit the last entry, or a specific file
+  $ tt edit
+  $ tt edit ~/.TimeTracker/2020/01/20200106-150000_nms.trc
+
+  # Register forgotten time
+  $ tt register 2020-01-01T09:00:00 17:00:00 -p "project-name"
+  $ tt register 2020-01-01T09:00:00 17:00:00 -p "project-name" -t "tag1,tag2"
+  $ tt register 2020-01-01T09:00:00 17:00:00 -p "project-name" -d "description" -t "tag1,tag2"
+
 Basic usage;
 
   # Start to track time
@@ -78,6 +80,27 @@ A more complex example:
   # you stopped working
   $ tt stop -t GITHUB-1005 "Today I was mostly in meetings" 15:24
 
+=head1 CONFIG
+
+Default configuration can be read from either C<$PWD/.env> or
+C<$HOME/.TimeTracker/config>. Here is an example config file with default
+settings:
+
+  # some comment
+  editor=nano
+  export_columns=date,project,hours,rounded,tags,description
+  hours_per_month=0  # Used to calculate how much you have to work
+  min_time=300       # Will drop the task on "tt stop" if started less than 300 seconds
+  round_up_at=30     # Used by the export comnmand to round hours
+
+Can also use the environment aliases:
+
+  EDITOR=vim
+  TT_COLUMNS=date,project
+  TT_HOURS_PER_MONTH=150
+  TT_MIN_TIME=600
+  TT_ROUND_UP_AT=15
+
 =head1 ACTIONS
 
 Each command can tak C<-h> for more details. Example:
